CollationManager

Struct CollationManager 

pub struct CollationManager<CF, V>
where CF: CollatorFactory,
{ /* private fields */ }

Implementations

Source

impl<CF, V> CollationManager<CF, V>
where CF: CollatorFactory, V: Validator,

pub fn start<STF, MPF>( keypair: Arc<KeyPair>, config: CollatorConfig, mq_adapter: Arc<dyn MessageQueueAdapter<EnqueuedMessage>>, state_node_adapter_factory: STF, mpool_adapter_factory: MPF, validator: V, collator_factory: CF, mempool_config_override: Option<MempoolGlobalConfig>, ) -> RunningCollationManager<CF, V>

pub async fn process_new_anchor_from_mempool( &self, _anchor: Arc<MempoolAnchor>, ) -> Result<()>

(TODO) Check sync status between mempool and blockchain state and pause collation when we are far behind other nodesб jusct sync blcoks from blockchain

pub async fn handle_collated_block_candidate( self: &Arc<Self>, collation_result: BlockCollationResult, ) -> Result<()>

Process collated block candidate

  1. Save block to cache
  2. Spawn block validation
  3. Check if the master block interval elapsed (according to chain time) and schedule collation
  4. If master block then update last master block chain time
  5. Notify mempool about new master block (it may perform gc or nodes rotation)
  6. Execute master block processing routines
pub async fn enqueue_handle_block_from_bc( &self, ctx: HandledBlockFromBcCtx, ) -> Result<()>

Finish active sync if it is not finished yet and enqueue received block

pub fn finish_collation_session( &self, collation_session: Arc<CollationSessionInfo>, ) -> Result<()>

Execute collation session finalization routines

pub fn handle_collator_stopped( &self, collation_session_id: (ShardIdent, u32, u32), ) -> Result<()>

Remove stopped collator from cache

pub async fn handle_validated_master_block( &self, block_id: BlockId, status: ValidationStatus, ) -> Result<()>

Process validated block

  1. Process invalid block (currently, just panic)
  2. Update block in cache with validation info
  3. Execute processing for master or shard block