pub struct StateUpdateContext {
pub mc_block_id: BlockId,
pub mc_block_chain_time: u64,
pub top_processed_to_anchor_id: MempoolAnchorId,
pub consensus_info: ConsensusInfo,
pub consensus_config: ConsensusConfig,
pub shuffle_validators: bool,
pub prev_validator_set: Option<(HashBytes, Arc<ValidatorSet>)>,
pub current_validator_set: (HashBytes, Arc<ValidatorSet>),
pub next_validator_set: Option<(HashBytes, Arc<ValidatorSet>)>,
}Fields
mc_block_id: BlockIdmc_block_chain_time: u64top_processed_to_anchor_id: MempoolAnchorIdconsensus_info: ConsensusInfoconsensus_config: ConsensusConfigshuffle_validators: boolprev_validator_set: Option<(HashBytes, Arc<ValidatorSet>)>current_validator_set: (HashBytes, Arc<ValidatorSet>)next_validator_set: Option<(HashBytes, Arc<ValidatorSet>)>Implementations
Sourceimpl StateUpdateContext
impl StateUpdateContext
Sourcepub fn vid(&self) -> VSetsId<'_>
pub fn vid(&self) -> VSetsId<'_>
equality by vid means all contained and derived v(sub)sets are the same
Sourcepub fn prev_v_set(&self) -> Vec<PeerId>
pub fn prev_v_set(&self) -> Vec<PeerId>
Preserves blockchain config peer order to pass into mempool
Sourcepub fn curr_v_set(&self) -> Vec<PeerId>
pub fn curr_v_set(&self) -> Vec<PeerId>
Preserves blockchain config peer order to pass into mempool
Sourcepub fn next_v_set(&self) -> Vec<PeerId>
pub fn next_v_set(&self) -> Vec<PeerId>
Preserves blockchain config peer order to pass into mempool