pub struct BlockCandidate {Show 14 fields
pub ref_by_mc_seqno: u32,
pub block: BlockStuffAug,
pub is_key_block: bool,
pub consensus_config_changed: Option<bool>,
pub prev_blocks_ids: Vec<BlockId>,
pub top_shard_blocks_ids: Vec<BlockId>,
pub collated_file_hash: HashBytes,
pub chain_time: u64,
pub processed_to_anchor_id: u32,
pub value_flow: ValueFlow,
pub created_by: HashBytes,
pub queue_diff_aug: QueueDiffStuffAug,
pub consensus_info: ConsensusInfo,
pub processed_upto: ProcessedUptoInfoStuff,
}Fields
ref_by_mc_seqno: u32block: BlockStuffAugis_key_block: boolconsensus_config_changed: Option<bool>If current block is a key master block and ConsensusConfig was changed.
None - if it is a shard block or not a key master block.
prev_blocks_ids: Vec<BlockId>top_shard_blocks_ids: Vec<BlockId>collated_file_hash: HashByteschain_time: u64processed_to_anchor_id: u32value_flow: ValueFlowcreated_by: HashBytesqueue_diff_aug: QueueDiffStuffAugconsensus_info: ConsensusInfoprocessed_upto: ProcessedUptoInfoStuffTrait Implementations
Sourceimpl Clone for BlockCandidate
impl Clone for BlockCandidate
Sourcefn clone(&self) -> BlockCandidate
fn clone(&self) -> BlockCandidate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for BlockCandidate
impl !RefUnwindSafe for BlockCandidate
impl Send for BlockCandidate
impl Sync for BlockCandidate
impl Unpin for BlockCandidate
impl UnsafeUnpin for BlockCandidate
impl !UnwindSafe for BlockCandidate