pub struct McData {Show 17 fields
pub global_id: i32,
pub block_id: BlockId,
pub prev_key_block_seqno: u32,
pub gen_lt: u64,
pub gen_chain_time: u64,
pub libraries: Dict<HashBytes, LibDescr>,
pub total_validator_fees: CurrencyCollection,
pub global_balance: CurrencyCollection,
pub shards: Vec<(ShardIdent, ShardDescriptionShort)>,
pub config: BlockchainConfig,
pub validator_info: ValidatorInfo,
pub consensus_info: ConsensusInfo,
pub processed_upto: ProcessedUptoInfoStuff,
pub top_processed_to_anchor: MempoolAnchorId,
pub ref_mc_state_handle: RefMcStateHandle,
pub shards_processed_to_by_partitions: FastHashMap<ShardIdent, (bool, ProcessedToByPartitions)>,
pub prev_mc_data: Option<PrevMcData>,
}Fields
global_id: i32block_id: BlockIdprev_key_block_seqno: u32Last known key block seqno. Will be equal to McData.block_id.seqno if it is a key block.
gen_lt: u64gen_chain_time: u64libraries: Dict<HashBytes, LibDescr>total_validator_fees: CurrencyCollectionglobal_balance: CurrencyCollectionshards: Vec<(ShardIdent, ShardDescriptionShort)>config: BlockchainConfigvalidator_info: ValidatorInfoconsensus_info: ConsensusInfoprocessed_upto: ProcessedUptoInfoStufftop_processed_to_anchor: MempoolAnchorIdMinimal of top processed to anchors from master block and its top shards
ref_mc_state_handle: RefMcStateHandleshards_processed_to_by_partitions: FastHashMap<ShardIdent, (bool, ProcessedToByPartitions)>prev_mc_data: Option<PrevMcData>Previous McData. Can be None on start from persistent or zerostate.
Implementations
Sourceimpl McData
impl McData
Sourcepub fn load_from_state(
state_stuff: &ShardStateStuff,
prev_mc_state: Option<&ShardStateStuff>,
all_shards_processed_to_by_partitions: FastHashMap<ShardIdent, (bool, ProcessedToByPartitions)>,
) -> Result<Arc<Self>>
pub fn load_from_state( state_stuff: &ShardStateStuff, prev_mc_state: Option<&ShardStateStuff>, all_shards_processed_to_by_partitions: FastHashMap<ShardIdent, (bool, ProcessedToByPartitions)>, ) -> Result<Arc<Self>>
Creates McData from mc state.
[all_shards_processed_to_by_partitions]: internals processed_to from master and all shards
pub fn make_block_ref(&self) -> BlockRef
pub fn lt_align(&self) -> u64
pub fn get_blocks_count_between_masters( &self, current_shard: &ShardIdent, ) -> u64