pub struct ValidatorSetCache { /* private fields */ }Implementations
Sourceimpl ValidatorSetCache
impl ValidatorSetCache
Sourcepub fn get_prev_validator_set(
&self,
config: &BlockchainConfig,
) -> Result<Option<(HashBytes, Arc<ValidatorSet>)>>
pub fn get_prev_validator_set( &self, config: &BlockchainConfig, ) -> Result<Option<(HashBytes, Arc<ValidatorSet>)>>
Returns cached previous validator set if hash was not changed, otherwise parses it from config.
Sourcepub fn get_current_validator_set(
&self,
config: &BlockchainConfig,
) -> Result<(HashBytes, Arc<ValidatorSet>)>
pub fn get_current_validator_set( &self, config: &BlockchainConfig, ) -> Result<(HashBytes, Arc<ValidatorSet>)>
Returns cached current validator set if hash was not changed, otherwise parses it from config.
Sourcepub fn get_next_validator_set(
&self,
config: &BlockchainConfig,
) -> Result<Option<(HashBytes, Arc<ValidatorSet>)>>
pub fn get_next_validator_set( &self, config: &BlockchainConfig, ) -> Result<Option<(HashBytes, Arc<ValidatorSet>)>>
Returns cached next validator set if hash was not changed, otherwise parses it from config.