pub struct InternalQueueTransaction {
pub db: InternalQueueDB,
pub batch: WriteBatch,
pub buffer: Vec<u8>,
}Fields
db: InternalQueueDBbatch: WriteBatchbuffer: Vec<u8>Implementations
Sourceimpl InternalQueueTransaction
impl InternalQueueTransaction
pub fn size(&self) -> (usize, usize)
pub fn write(self) -> Result<()>
pub fn insert_statistics(&mut self, key: &StatKey, count: u64)
pub fn insert_diff_tail(&mut self, key: &DiffTailKey, value: &[u8])
pub fn insert_diff_info(&mut self, key: &DiffInfoKey, value: &[u8])
pub fn insert_message( &mut self, key: &ShardsInternalMessagesKey, dest: &IntAddr, value: &[u8], )
Sourcepub fn commit_messages(
&mut self,
commit_pointers: FastHashMap<ShardIdent, (QueueKey, u32)>,
) -> Result<()>
pub fn commit_messages( &mut self, commit_pointers: FastHashMap<ShardIdent, (QueueKey, u32)>, ) -> Result<()>
Updates commit pointers in message queue. ATTENTION! Overrides old value without checks. Should validate the new value in the calling code.
Sourcepub fn clear_uncommitted(
&self,
partitions: &FastHashSet<QueuePartitionIdx>,
commit_pointers: &FastHashMap<ShardIdent, CommitPointerValue>,
top_shards: &[ShardIdent],
) -> Result<()>
pub fn clear_uncommitted( &self, partitions: &FastHashSet<QueuePartitionIdx>, commit_pointers: &FastHashMap<ShardIdent, CommitPointerValue>, top_shards: &[ShardIdent], ) -> Result<()>
Removes all keys that are strictly above the committed pointers in each partition.
(Anything above pointer + 1 is considered “uncommitted” and will be deleted.)
commit_pointers: a map of (ShardIdent-> last committedQueueKey)partitions: a list of partitions (e.g. 0..255) to cleartop_shards: a list of all shards for backoff when no commit pointers
pub fn delete(&self, ranges: &[QueueRange]) -> Result<()>
Sourcepub fn set_last_committed_mc_block_id(
&mut self,
mc_block_id: &BlockId,
) -> Result<()>
pub fn set_last_committed_mc_block_id( &mut self, mc_block_id: &BlockId, ) -> Result<()>
Stores mc block id on which the queue was committed. ATTENTION! Overrides old value without checks. Should validate the new value in the calling code.